intelmq.bots.collectors.amqp package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.amqp package

## Submodules

## intelmq.bots.collectors.amqp.collector_amqp module

Collecting from a (remote) AMQP Server and fetching either intelmq or any other messages.

class `intelmq.bots.collectors.amqp.collector_amqp.` `AMQPCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.bots.outputs.amqptopic.output.AMQPTopicOutputBot`, `intelmq.lib.bot.CollectorBot`

  Inheriting from AMQPTopicOutputBot for connect_server method

  `exchange` = False
  `init`()
  `process`()

    Stop the Bot if cannot connect to AMQP Server after the defined connection attempts

`intelmq.bots.collectors.amqp.collector_amqp.` `BOT`

  alias of `intelmq.bots.collectors.amqp.collector_amqp.AMQPCollectorBot`

## Module contents